BOOST_PP_VARIADIC_SEQ_TO_SEQ

The BOOST_PP_VARIADIC_SEQ_TO_SEQ variadic macro converts a variadic seq to a seq.

#### Usage

BOOST_PP_VARIADIC_SEQ_TO_SEQ(vseq)(v)

#### Arguments

vseq
  The variadic seq to be converted.

#### Requirements

Header: <boost/preprocessor/seq/variadic_seq_to_seq.hpp>

#### Sample Code

    #include <boost/preprocessor/seq/variadic_seq_to_seq.hpp>

    BOOST_PP_VARIADIC_SEQ_TO_SEQ((1)(2, 3)(4, 5, 6)) // expands to ((1))((2, 3))((4, 5, 6))

© Copyright Paul Mensonides 2012

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)